pub struct DeviceSignal(/* private fields */);Implementations
Sourceimpl DeviceSignal
impl DeviceSignal
Sourcepub const READABLE: DeviceSignal
pub const READABLE: DeviceSignal
Indicates the device is ready for reading.
Sourcepub const OOB: DeviceSignal
pub const OOB: DeviceSignal
Indicates an out-of-band state transition has occurred.
Sourcepub const WRITABLE: DeviceSignal
pub const WRITABLE: DeviceSignal
Indicates the device is ready for writing.
Sourcepub const ERROR: DeviceSignal
pub const ERROR: DeviceSignal
Indicates the device has encountered an error state.
Sourcepub const HANGUP: DeviceSignal
pub const HANGUP: DeviceSignal
Indicates the device has hung up on the current connection.
Sourceimpl DeviceSignal
impl DeviceSignal
Sourcepub const fn empty() -> DeviceSignal
pub const fn empty() -> DeviceSignal
Get a flags value with all bits unset.
Sourcepub const fn all() -> DeviceSignal
pub const fn all() -> DeviceSignal
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<DeviceSignal>
pub const fn from_bits(bits: u32) -> Option<DeviceSignal>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> DeviceSignal
pub const fn from_bits_truncate(bits: u32) -> DeviceSignal
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> DeviceSignal
pub const fn from_bits_retain(bits: u32) -> DeviceSignal
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<DeviceSignal>
pub fn from_name(name: &str) -> Option<DeviceSignal>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: DeviceSignal) -> bool
pub const fn intersects(&self, other: DeviceSignal) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: DeviceSignal) -> bool
pub const fn contains(&self, other: DeviceSignal) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: DeviceSignal)
pub fn insert(&mut self, other: DeviceSignal)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: DeviceSignal)
pub fn remove(&mut self, other: DeviceSignal)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: DeviceSignal)
pub fn toggle(&mut self, other: DeviceSignal)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: DeviceSignal, value: bool)
pub fn set(&mut self, other: DeviceSignal, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: DeviceSignal) -> DeviceSignal
pub const fn intersection(self, other: DeviceSignal) -> DeviceSignal
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: DeviceSignal) -> DeviceSignal
pub const fn union(self, other: DeviceSignal) -> DeviceSignal
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: DeviceSignal) -> DeviceSignal
pub const fn difference(self, other: DeviceSignal) -> DeviceSignal
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: DeviceSignal) -> DeviceSignal
pub const fn symmetric_difference(self, other: DeviceSignal) -> DeviceSignal
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> DeviceSignal
pub const fn complement(self) -> DeviceSignal
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl DeviceSignal
impl DeviceSignal
Sourcepub const fn iter(&self) -> Iter<DeviceSignal> ⓘ
pub const fn iter(&self) -> Iter<DeviceSignal> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DeviceSignal> ⓘ
pub const fn iter_names(&self) -> IterNames<DeviceSignal> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.